@@ -13,23 +13,24 @@
 #       Create: 2018-07-07 17:26
 #=============================================================================
 """
-import os
 import argparse
-import sys
+import os
 import subprocess
+import sys
 
 from .conf import PathConfig
-from .utils.sshconf import merge_ssh_config
-from .utils.utils import run_cmd
-from .utils.utils import get_file_abspath
-from .utils.utils import YmlConfig
+from .exceptions import RunCmdError
+from .exceptions import SystemTypeError
 from .utils.printer import print_error
-from .utils.printer import print_text
 from .utils.printer import print_ok
-from .exceptions import RunCmdError, SystemTypeError
+from .utils.printer import print_text
+from .utils.sshconf import merge_ssh_config
+from .utils.utils import YmlConfig
+from .utils.utils import get_file_abspath
+from .utils.utils import run_cmd
 
 
-def get_project_conf(project, src, dest, delete, exclude):
+def get_project_conf(project, src, dest, delete, exclude, is_download=False):
     """查询项目信息
 
     :param project 指定的项目名
@@ -45,13 +46,17 @@ def get_project_conf(project, src, dest, delete, exclude):
     :example dest /tmp
 
     :param exclude 需要过滤的目录
-    :type exclude str
+    :type exclude list
     :example exclude [".git"]
 
     :param delete 是否删除远程机器目录下非本次上传的文件
     :type delete int
     :example delete 0 0|1  0: 不删除 1: 删除
 
+    :param is_download 是否下载文件
+    :type is_download bool
+    :example is_download True True|False
+
     :rtype data dict
     :return data 项目的配置信息
     {
@@ -73,7 +78,9 @@ def get_project_conf(project, src, dest, delete, exclude):
         data = yml_data["projects"][project]
     except KeyError:
         if not (src and dest):
-            print_error("yml文件: %s 中没有配置项目: %s 的信息" % (PathConfig.plum_yml_path, project))
+            print_error(
+                "yml文件: %s 中没有配置项目: %s 的信息" % (PathConfig.plum_yml_path, project)
+            )
             sys.exit(1)
 
     # 设置默认值
@@ -83,6 +90,17 @@ def get_project_conf(project, src, dest, delete, exclude):
     # 从命令行中更新对应值
     if src:
         data["src"] = src
+
+    # 上传时对本地路径取绝对路径
+    if not is_download:
+        try:
+            data["src"] = get_file_abspath(data["src"])
+        except RunCmdError:
+            print_error("%s 文件/目录不存在" % src)
+            sys.exit(1)
+        except SystemTypeError as e:
+            print_error(str(e))
+            sys.exit(1)
     if dest:
         data["dest"] = dest
     if delete is not None:  # 默认值为None
@@ -94,12 +112,22 @@ def get_project_conf(project, src, dest, delete, exclude):
 
 
 class SyncFiles(object):
-    """上传文件到服务器
-    """
+    """上传文件到服务器"""
 
     # pylint: disable=R0913
-    def __init__(self, hostname, user, port, identityfile, src, dest, exclude, delete, is_download=False,
-                 is_debug=False):
+    def __init__(
+        self,
+        hostname,
+        user,
+        port,
+        identityfile,
+        src,
+        dest,
+        exclude,
+        delete,
+        is_download=False,
+        is_debug=False,
+    ):
         """文件上传功能
 
         :param hostname 主机ip
@@ -154,8 +182,7 @@ class SyncFiles(object):
         self._is_debug = is_debug
 
     def _get_sync_option(self):
-        """组合出同步文件的命令
-        """
+        """组合出同步文件的命令"""
         option = ["rsync -rtv"]
         known_host = "UserKnownHostsFile=/dev/null"
         host_key = "StrictHostKeyChecking no"
@@ -165,9 +192,13 @@ class SyncFiles(object):
             ssh_cmd = "ssh -p %d" % self._port
         else:
             ssh_cmd = "ssh"
-        option.append("'--rsync-path=mkdir -p %s && rsync'" % os.path.dirname(self._dest))
-        option.append("-e '%s -i %s -o \"%s\" -o \"%s\" -o \"%s\"'" % (
-            ssh_cmd, self._identity_file, known_host, host_key, timeout))
+        option.append(
+            "'--rsync-path=mkdir -p %s && rsync'" % os.path.dirname(self._dest)
+        )
+        option.append(
+            '-e \'%s -i %s -o "%s" -o "%s" -o "%s"\''
+            % (ssh_cmd, self._identity_file, known_host, host_key, timeout)
+        )
         if self._delete:
             option.append(" --delete")
         for item in set(self._exclude):
@@ -175,8 +206,7 @@ class SyncFiles(object):
         return " ".join(option)
 
     def translate(self):
-        """文件上传功能
-        """
+        """文件上传功能"""
         # pv = "|pv -lep -s 117 >/dev/null"
         pv = ""
 
@@ -195,13 +225,23 @@ class SyncFiles(object):
             src = "%s@%s:%s%s" % (self._user, self._hostname, self._src, pv)
             dest = self._dest
             text = "从 %s@%s 服务器(端口: %s) 下载目录 %s 到本地 %s " % (
-                self._user, self._hostname, self._port, self._src, self._dest)
+                self._user,
+                self._hostname,
+                self._port,
+                self._src,
+                self._dest,
+            )
         # 从本地上传文件到远端
         else:
             src = self._src
             dest = "%s@%s:%s%s" % (self._user, self._hostname, self._dest, pv)
             text = "上传目录 %s 到 %s@%s 服务器(端口: %s) %s 目录" % (
-                self._src, self._user, self._hostname, self._port, self._dest)
+                self._src,
+                self._user,
+                self._hostname,
+                self._port,
+                self._dest,
+            )
 
         rsync = self._get_sync_option()
         cmd = "%s %s %s" % (rsync, src, dest)
@@ -216,7 +256,16 @@ class SyncFiles(object):
             print_error("%s失败, 失败原因: %s" % (text, e.err_msg))
 
 
-def sync_files(host_list, host_type, user, port, identity_file, projects_conf, is_download=False, is_debug=False):
+def sync_files(
+    host_list,
+    host_type,
+    user,
+    port,
+    identity_file,
+    projects_conf,
+    is_download=False,
+    is_debug=False,
+):
     """上传文件到服务器上
 
     :param host_list 服务器列表
@@ -270,86 +319,118 @@ def sync_files(host_list, host_type, user, port, identity_file, projects_conf, i
 
 
 def main():  # pylint: disable=R0914
-    """程序主入口
-    """
+    """程序主入口"""
     parser = argparse.ArgumentParser()
-    parser.add_argument("-s", "--servers",
-                        required=True,
-                        action="store",
-                        dest="servers",
-                        nargs="+",
-                        help="specify server")
-    parser.add_argument("-p", "--projects",
-                        required=False,
-                        action="store",
-                        dest="projects",
-                        nargs="+",
-                        default=["default"],
-                        help="specify project")
+    parser.add_argument(
+        "-s",
+        "--servers",
+        required=True,
+        action="store",
+        dest="servers",
+        nargs="+",
+        help="specify server",
+    )
+    parser.add_argument(
+        "-p",
+        "--projects",
+        required=False,
+        action="store",
+        dest="projects",
+        nargs="+",
+        default=["default"],
+        help="specify project",
+    )
 
-    parser.add_argument("-t", "--type",
-                        action="store",
-                        required=False,
-                        dest="type",
-                        default="default",
-                        help="host type")
-    parser.add_argument("--download",
-                        action="store_true",
-                        required=False,
-                        dest="download",
-                        default=False,
-                        help="Download the file locally")
-    parser.add_argument("-i", "--identityfile",
-                        action="store",
-                        required=False,
-                        dest="identity_file",
-                        default="",
-                        help="ssh login identityfile path")
-    parser.add_argument("-u", "--username",
-                        action="store",
-                        required=False,
-                        dest="user",
-                        default="",
-                        help="ssh login username")
-    parser.add_argument("--port",
-                        action="store",
-                        required=False,
-                        dest="port",
-                        type=int,
-                        default=0,
-                        help="ssh login port")
-    parser.add_argument("-l", "--local",
-                        action="store",
-                        required=False,
-                        dest="local",
-                        default="",
-                        help="local path")
-    parser.add_argument("-r", "--remote",
-                        action="store",
-                        required=False,
-                        dest="remote",
-                        default="",
-                        help="remote path")
-    parser.add_argument("-d", "--delete",
-                        action="store",
-                        required=False,
-                        dest="delete",
-                        type=int,
-                        default=None,
-                        help="delete remote path other file")
-    parser.add_argument("-e", "--exclude",
-                        action="store",
-                        nargs="+",
-                        required=False,
-                        dest="exclude",
-                        default=[],
-                        help="exclude file")
-    parser.add_argument("--debug",
-                        action="store_true",
-                        required=False,
-                        dest="debug",
-                        default=False,
-                        help="debug output from parser")
+    parser.add_argument(
+        "-t",
+        "--type",
+        action="store",
+        required=False,
+        dest="type",
+        default="default",
+        help="host type",
+    )
+    parser.add_argument(
+        "--download",
+        action="store_true",
+        required=False,
+        dest="download",
+        default=False,
+        help="Download the file locally",
+    )
+    parser.add_argument(
+        "-i",
+        "--identityfile",
+        action="store",
+        required=False,
+        dest="identity_file",
+        default="",
+        help="ssh login identityfile path",
+    )
+    parser.add_argument(
+        "-u",
+        "--username",
+        action="store",
+        required=False,
+        dest="user",
+        default="",
+        help="ssh login username",
+    )
+    parser.add_argument(
+        "--port",
+        action="store",
+        required=False,
+        dest="port",
+        type=int,
+        default=0,
+        help="ssh login port",
+    )
+    parser.add_argument(
+        "-l",
+        "--local",
+        action="store",
+        required=False,
+        dest="local",
+        default="",
+        help="local path",
+    )
+    parser.add_argument(
+        "-r",
+        "--remote",
+        action="store",
+        required=False,
+        dest="remote",
+        default="",
+        help="remote path",
+    )
+    parser.add_argument(
+        "-d",
+        "--delete",
+        action="store",
+        required=False,
+        dest="delete",
+        type=int,
+        default=None,
+        help="delete remote path other file",
+    )
+    parser.add_argument(
+        "-e",
+        "--exclude",
+        action="store",
+        nargs="+",
+        required=False,
+        dest="exclude",
+        default=[],
+        help="exclude file",
+    )
+    parser.add_argument(
+        "--debug",
+        action="store_true",
+        required=False,
+        dest="debug",
+        default=False,
+        help="debug output from parser",
+    )
 
     args = parser.parse_args()
     host_list, host_type, projects = args.servers, args.type, args.projects
@@ -360,16 +441,17 @@ def main():  # pylint: disable=R0914
 
     is_download, is_debug = args.download, args.debug
 
-    # 上传时对本地路径取绝对路径
-    if not is_download:
-        try:
-            src = get_file_abspath(src)
-        except RunCmdError:
-            print_error("%s 文件/目录不存在" % src)
-            return
-        except SystemTypeError as e:
-            print_error(str(e))
-            return
-
-    projects_conf = [get_project_conf(project, src, dest, delete, exclude) for project in projects]
-    sync_files(host_list, host_type, user, port, identity_file, projects_conf, is_download, is_debug)
+    projects_conf = [
+        get_project_conf(project, src, dest, delete, exclude, is_download)
+        for project in projects
+    ]
+    sync_files(
+        host_list,
+        host_type,
+        user,
+        port,
+        identity_file,
+        projects_conf,
+        is_download,
+        is_debug,
+    )
